aboutsummaryrefslogtreecommitdiffstats
path: root/include/zot.php
diff options
context:
space:
mode:
authorredmatrix <redmatrix@redmatrix.me>2015-09-19 22:46:59 -0700
committerredmatrix <redmatrix@redmatrix.me>2015-09-19 22:46:59 -0700
commit5d6f59a598fdf700b90d7d14bb5c9087c0968cb9 (patch)
tree18422dbbca076ac5a77aa57e5489ec2e0a3f6a74 /include/zot.php
parent63146821d7f28107ca34fbe581dcc3abf6fd49fe (diff)
downloadvolse-hubzilla-5d6f59a598fdf700b90d7d14bb5c9087c0968cb9.tar.gz
volse-hubzilla-5d6f59a598fdf700b90d7d14bb5c9087c0968cb9.tar.bz2
volse-hubzilla-5d6f59a598fdf700b90d7d14bb5c9087c0968cb9.zip
clone new connections
Diffstat (limited to 'include/zot.php')
-rw-r--r--include/zot.php35
1 files changed, 18 insertions, 17 deletions
diff --git a/include/zot.php b/include/zot.php
index 6c5a8c289..52ae23ba5 100644
--- a/include/zot.php
+++ b/include/zot.php
@@ -487,20 +487,16 @@ function zot_refresh($them, $channel = null, $force = false) {
if($y) {
logger("New introduction received for {$channel['channel_name']}");
$new_perms = get_all_perms($channel['channel_id'],$x['hash']);
- if($new_perms != $previous_perms) {
- // Send back a permissions update if permissions have changed
- $z = q("select * from abook where abook_xchan = '%s' and abook_channel = %d and abook_self = 0 limit 1",
- dbesc($x['hash']),
- intval($channel['channel_id'])
- );
- if($z)
- proc_run('php','include/notifier.php','permission_update',$z[0]['abook_id']);
- }
- $new_connection = q("select abook_id, abook_pending from abook where abook_channel = %d and abook_xchan = '%s' order by abook_created desc limit 1",
- intval($channel['channel_id']),
- dbesc($x['hash'])
+
+ // Send a clone sync packet and a permissions update if permissions have changed
+ $new_connection = q("select * from abook where abook_xchan = '%s' and abook_channel = %d and abook_self = 0 order by abook_created desc limit 1",
+ dbesc($x['hash']),
+ intval($channel['channel_id'])
);
+
if($new_connection) {
+ if($new_perms != $previous_perms)
+ proc_run('php','include/notifier.php','permission_update',$new_connection[0]['abook_id']);
require_once('include/enotify.php');
notification(array(
'type' => NOTIFY_INTRO,
@@ -508,12 +504,17 @@ function zot_refresh($them, $channel = null, $force = false) {
'to_xchan' => $channel['channel_hash'],
'link' => z_root() . '/connedit/' . $new_connection[0]['abook_id'],
));
- }
+
+ if($their_perms & PERMS_R_STREAM) {
+ if(($channel['channel_w_stream'] & PERMS_PENDING)
+ || (! intval($new_connection[0]['abook_pending'])) )
+ proc_run('php','include/onepoll.php',$new_connection[0]['abook_id']);
+ }
- if($new_connection && ($their_perms & PERMS_R_STREAM)) {
- if(($channel['channel_w_stream'] & PERMS_PENDING)
- || (! intval($new_connection[0]['abook_pending'])) )
- proc_run('php','include/onepoll.php',$new_connection[0]['abook_id']);
+ unset($new_connection[0]['abook_id']);
+ unset($new_connection[0]['abook_account']);
+ unset($new_connection[0]['abook_channel']);
+ build_sync_packet($channel['channel_id'], array('abook' => $new_connection));
}
}
}